[−][src]Crate kerbalobjects
Structs
| DebugEntry | |
| DebugSection | |
| HeaderTable | |
| KOFile | A structure that represents an entire KO file |
| KOFileReader | |
| KOFileWriter | |
| KOHeader | |
| RelInstruction | |
| RelSection | |
| SectionHeader | |
| StringTable | Represents a list of strings in a KO file that can be used as the names of symbols or as file comments or notes |
| Symbol | Represents a single symbol in an object file. This can be a function, an object, program data, or anything else. |
| SymbolDataSection | |
| SymbolTable |
Enums
| KOSValue | |
| SectionType | |
| SymbolInfo | |
| SymbolType |
Statics
| FILE_VERSION | |
| MAGIC_NUMBER |